@@ -658,9 +658,9 @@ class UnitTestCase(TestCase):
             u"&nbsp;&nbsp;&nbsp;page2"
         )
         p = Page(author=page1.author)
-        self.assertEqual(unicode(p), u"Page without id")
+        self.assertEqual(str(p), u"Page without id")
         p.save()
-        self.assertEqual(unicode(p), u"Page %d" % p.id)
+        self.assertEqual(str(p), u"Page %d" % p.id)
 
     def test_context_processor(self):
         """Test that the page's context processor is properly activated."""
@@ -674,7 +674,7 @@ class UnitTestCase(TestCase):
     def test_get_page_from_id_context_variable(self):
         """Test get_page_from_string_or_id with an id context variable."""
         page = self.new_page({'slug': 'test'})
-        self.assertEqual(get_page_from_string_or_id(unicode(page.id)), page)
+        self.assertEqual(get_page_from_string_or_id(str(page.id)), page)
 
         content = Content(page=page, language='en-us', type='test_id',
             body=page.id)
